load_config

Function load_config 

pub fn load_config(path: &Path) -> Result<Option<AgentExecConfig>>
Load and parse a config file from the given path.

Returns Ok(None) if the file does not exist. Returns Err if the file exists but cannot be parsed.