pub fn resolve_config(
config_path_override: Option<&str>,
) -> Result<AgentExecConfig>Expand description
Resolve and load the effective config from explicit path or XDG default.
pub fn resolve_config(
config_path_override: Option<&str>,
) -> Result<AgentExecConfig>Resolve and load the effective config from explicit path or XDG default.