Module create

Module create 

Implementation of the create sub-command.

create persists a full job definition without launching the supervisor or child process. The job is left in created state so that start can launch it later.

Structs

CreateOpts
Options for the create sub-command.

Functions

execute
Execute create: persist job definition and return JSON.