build_output_match_config

Function build_output_match_config 

pub fn build_output_match_config(
    output_pattern: Option<String>,
    output_match_type: Option<String>,
    output_stream: Option<String>,
    output_command: Option<String>,
    output_file: Option<String>,
    existing: Option<OutputMatchConfig>,
) -> Option<OutputMatchConfig>
Build an updated OutputMatchConfig by merging provided options with existing config.

  • If output_pattern is provided, a new config is created from scratch using provided values (with defaults for unspecified fields).
  • If no new pattern is provided but other output-match fields are provided, they overlay the existing config.
  • If nothing is provided and there’s no existing config, returns None.