Implementation of the restart sub-command.
restart reuses an existing job directory and persisted meta.json definition
while replacing the current process, if any, with a fresh supervisor launch.
Structs
- Restart
Opts - Options for the
restartsub-command.
Functions
- execute
- Execute
restart: replace an existing job’s current run and return JSON.