observe_inline_output

Function observe_inline_output 

pub fn observe_inline_output(
    job_dir: &JobDir,
    wait: bool,
    until_seconds: u64,
    forever: bool,
    max_bytes: u64,
) -> Result<InlineObservation>
Resolve the effective working directory for a job.

If cwd_override is Some, use that path as the base. Otherwise use the current process working directory. In either case, attempt to canonicalize the path for consistent comparison; on failure, fall back to the absolute path representation (avoids symlink / permission issues on some systems).