pub struct InstalledSkillSummary {
pub name: String,
pub source_type: String,
pub path: String,
}Expand description
Summary of a single installed skill, included in install_skills responses.
Fields
name: StringSkill name (directory name under .agents/skills/).
source_type: StringSource type string used when the skill was installed (e.g. “self”, “local”).
path: StringAbsolute path to the installed skill directory.