RunData

Struct RunData 

pub struct RunData {
Show 19 fields pub job_id: String, pub state: String, pub tags: Vec<String>, pub env_vars: Vec<String>, pub stdout_log_path: String, pub stderr_log_path: String, pub elapsed_ms: u64, pub waited_ms: u64, pub stdout: String, pub stderr: String, pub stdout_range: [u64; 2], pub stderr_range: [u64; 2], pub stdout_total_bytes: u64, pub stderr_total_bytes: u64, pub encoding: String, pub exit_code: Option<i32>, pub finished_at: Option<String>, pub signal: Option<String>, pub duration_ms: Option<u64>,
}
Response for run command.

Fields

job_id: Stringstate: Stringtags: Vec<String>

Tags assigned to this job (always present; empty array when none).

env_vars: Vec<String>

Environment variables passed to the job, with masked values replaced by “***”. Omitted from JSON when empty.

stdout_log_path: String

Absolute path to stdout.log for this job.

stderr_log_path: String

Absolute path to stderr.log for this job.

elapsed_ms: u64

Wall-clock milliseconds from run/start invocation start to JSON output.

waited_ms: u64

Time spent waiting for inline output observation.

stdout: String

UTF-8 lossy stdout excerpt.

stderr: String

UTF-8 lossy stderr excerpt.

stdout_range: [u64; 2]

Raw stdout byte range represented by stdout as [begin, end).

stderr_range: [u64; 2]

Raw stderr byte range represented by stderr as [begin, end).

stdout_total_bytes: u64

Total bytes currently observed in stdout.log.

stderr_total_bytes: u64

Total bytes currently observed in stderr.log.

encoding: String

Encoding contract for stdout/stderr excerpts.

exit_code: Option<i32>

Exit code when terminal.

finished_at: Option<String>

Finished-at timestamp when terminal.

signal: Option<String>

POSIX signal name when terminated by signal (e.g. “SIGTERM”).

duration_ms: Option<u64>

Wall-clock milliseconds from started_at to finished_at.