pub struct Snapshot {
pub stdout_tail: String,
pub stderr_tail: String,
pub truncated: bool,
pub encoding: String,
pub stdout_observed_bytes: u64,
pub stderr_observed_bytes: u64,
pub stdout_included_bytes: u64,
pub stderr_included_bytes: u64,
}Expand description
Snapshot of stdout/stderr tail at a point in time.
Fields
stdout_tail: Stringstderr_tail: Stringtruncated: boolTrue when the output was truncated by tail_lines or max_bytes constraints.
encoding: Stringstdout_observed_bytes: u64Size of stdout.log in bytes at the time of the snapshot (0 if file absent).
stderr_observed_bytes: u64Size of stderr.log in bytes at the time of the snapshot (0 if file absent).
stdout_included_bytes: u64UTF-8 byte length of the stdout_tail string included in this snapshot.
stderr_included_bytes: u64UTF-8 byte length of the stderr_tail string included in this snapshot.