pub struct TailData {
pub job_id: String,
pub stdout_tail: String,
pub stderr_tail: String,
pub truncated: bool,
pub encoding: String,
pub stdout_log_path: String,
pub stderr_log_path: String,
pub stdout_observed_bytes: u64,
pub stderr_observed_bytes: u64,
pub stdout_included_bytes: u64,
pub stderr_included_bytes: u64,
}Expand description
Response for tail command.
Fields
job_id: Stringstdout_tail: Stringstderr_tail: Stringtruncated: boolTrue when the output was truncated by tail_lines or max_bytes constraints.
encoding: Stringstdout_log_path: StringAbsolute path to stdout.log for this job.
stderr_log_path: StringAbsolute path to stderr.log for this job.
stdout_observed_bytes: u64Size of stdout.log in bytes at the time of the tail read (0 if file absent).
stderr_observed_bytes: u64Size of stderr.log in bytes at the time of the tail read (0 if file absent).
stdout_included_bytes: u64UTF-8 byte length of the stdout_tail string included in this response.
stderr_included_bytes: u64UTF-8 byte length of the stderr_tail string included in this response.