pub fn execute(_opts: SchemaOpts) -> Result<()>Expand description
Execute the schema subcommand.
Loads the bundled JSON Schema from a path relative to the binary and prints a JSON envelope to stdout.
pub fn execute(_opts: SchemaOpts) -> Result<()>Execute the schema subcommand.
Loads the bundled JSON Schema from a path relative to the binary and prints a JSON envelope to stdout.