pub struct LockFile {
pub skills: Vec<LockEntry>,
}Expand description
Represents the .agents/.skill-lock.json file.
Fields
skills: Vec<LockEntry>Ordered list of installed skills.
Implementations
Sourceimpl LockFile
impl LockFile
Sourcepub fn read(path: &Path) -> Result<Self>
pub fn read(path: &Path) -> Result<Self>
Read the lock file from disk. Returns an empty lock file if it does not exist. Supports the legacy map format by ignoring unknown shapes gracefully.