pub struct TailOpts<'a> {
pub job_id: &'a str,
pub root: Option<&'a str>,
pub tail_lines: u64,
pub max_bytes: u64,
}Expand description
Options for the tail sub-command.
Fields
job_id: &'a strroot: Option<&'a str>tail_lines: u64Number of lines to show from the end of each log.
max_bytes: u64Maximum bytes to read from the end of each log.