pub fn resolve_root_for_completion() -> PathBufExpand description
Resolve the root directory to use during a completion invocation.
Tries, in order:
--root <value>extracted fromCOMP_LINE(bash/zsh).--root <value>extracted from the process argv after the--separator (covers fish and other shells that pass words as argv).AGENT_EXEC_ROOTenvironment variable (viaresolve_root(None)).- XDG / platform default (via
resolve_root(None)).