Implementation of the run sub-command.
Design decisions (from design.md):
runspawns a short-lived front-end that forks a_supervisechild.- The supervisor continues logging stdout/stderr after
runreturns. - If
--snapshot-afterelapses beforerunreturns, a snapshot is included in the JSON response.
Structs
- RunOpts
- Options for the
runsub-command. - Supervise
Opts - Options for the
_superviseinternal sub-command.
Functions
- execute
- Execute
run: spawn job, possibly wait for snapshot, return JSON. - now_
rfc3339_ pub - Public alias so other modules can call the timestamp helper.
- resolve_
effective_ cwd - Resolve the effective working directory for a job.
- supervise
- Internal supervisor sub-command.