pub struct TailData {
pub job_id: String,
pub stdout: String,
pub stderr: String,
pub encoding: String,
pub stdout_log_path: String,
pub stderr_log_path: String,
pub stdout_range: [u64; 2],
pub stderr_range: [u64; 2],
pub stdout_total_bytes: u64,
pub stderr_total_bytes: u64,
}Expand description
Response for tail command.
Fields
job_id: Stringstdout: Stringstderr: Stringencoding: Stringstdout_log_path: StringAbsolute path to stdout.log for this job.
stderr_log_path: StringAbsolute path to stderr.log for this job.
stdout_range: [u64; 2]Raw stdout byte range represented by stdout as [begin, end).
stderr_range: [u64; 2]Raw stderr byte range represented by stderr as [begin, end).
stdout_total_bytes: u64Total bytes currently observed in stdout.log.
stderr_total_bytes: u64Total bytes currently observed in stderr.log.